WriteBuilder

Struct WriteBuilder 

pub struct WriteBuilder { /* private fields */ }
Build a Data Shifting Command set to write bytes.

Implementations

Source

impl WriteBuilder

pub fn with_clock_direction(self, direction: ClockEdge) -> Self

Set this command to write the bits on a specific clock edge.

By default, the WriteBuilder will build the command with the clock direction set Rising (meaning read on the rising clock).

use mpsse::{Builder, ClockEdge};

let commands = Builder::new()
    .write_data(vec![0x01])
    .with_clock_direction(ClockEdge::Rising)
    .then()
    .write_data(vec![0x01])
    .with_clock_direction(ClockEdge::Falling)
    .build();

assert_eq!(commands, vec![0x10, 0x00, 0x00, 0x01, 0x11, 0x00, 0x00, 0x01])
pub fn with_bit_direction(self, direction: BitDirection) -> Self

Set this command to write the bits in a specific direction

By default, the WriteBuilder will build the command with the bit direction set MsbFirst.

use mpsse::{Builder, BitDirection};

let commands = Builder::new()
    .write_data(vec![0x01])
    .with_bit_direction(BitDirection::MsbFirst)
    .then()
    .write_data(vec![0x01])
    .with_bit_direction(BitDirection::LsbFirst)
    .build();

assert_eq!(commands, vec![0x10, 0x00, 0x00, 0x01, 0x18, 0x00, 0x00, 0x01])
pub fn then(self) -> Builder

Same as commit, but more readable in a chain.

pub fn build(self) -> Vec<u8>

Commit this command to the parent Builder, then get the entire command list as a byte sequence.